pub type C_DigestKey = extern "C" fn(hSession: CK_SESSION_HANDLE, hKey: CK_OBJECT_HANDLE) -> CK_RV;Expand description
C_DigestKey continues a multi-part message-digesting operation, by digesting the value of a secret key as part of the data already digested.
Function Parameters
hSession: the session’s handlehKey: secret key to digest